All Classes and Interfaces

Class
Description
The Amazon Redshift Data API operation failed because the maximum number of active sessions exceeded.
 
The number of active statements exceeds the limit.
 
An AWS Arn.
 
An SQL statement encountered an environmental error while running.
 
 
 
 
 
 
 
 
 
The properties (metadata) of a column.
 
Connection to a database failed.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Link between an endpoint property and the AwsEndpointAttribute it represents.
 
 
The SQL statement encountered an environmental error while running.
 
 
 
 
 
A data value in a column.
 
 
 
 
 
 
 
 
 
 
Identifiers for variables declared within the rule engine, e.g.
The Amazon Redshift Data API operation failed due to invalid input.
 
 
 
 
 
 
 
 
 
 
 
 
 
Represents the output for the RedshiftDataClient.listTablesPaginator(software.amazon.awssdk.services.redshiftdata.model.ListTablesRequest) operation which is a paginated operation.
 
 
 
 
 
 
 
 
 
 
 
 
The results of the SQL statement.
 
 
The Amazon Redshift Data API operation failed due to timeout.
 
Service client for accessing Redshift Data API Service asynchronously.
A builder for creating an instance of RedshiftDataAsyncClient.
 
The parameters object used to resolve the auth schemes for the RedshiftData service.
An auth scheme provider for RedshiftData service.
This includes configuration specific to Redshift Data API Service that is supported by both RedshiftDataClientBuilder and RedshiftDataAsyncClientBuilder.
Service client for accessing Redshift Data API Service.
A builder for creating an instance of RedshiftDataClient.
 
The parameters object used to resolve an endpoint for the RedshiftData service.
 
An endpoint provider for RedshiftData.
 
 
 
 
 
 
 
 
 
 
 
 
Class to expose the service client settings to the user.
 
 
 
The Amazon Redshift Data API operation failed due to a missing resource.
 
 
 
 
 
 
 
Represents a URL to be used internally for endpoint resolution.
 
A parameter used in a SQL statement.
 
The SQL statement to run.
 
 
 
Information about an SQL statement.
 
The properties of a table.
 
 
The Amazon Redshift Data API operation failed due to invalid input.
 
Base class for the types of values computable by the RuleEngine.
An array value.
A boolean value.
 
 
An integer value.
 
A record (map) value.
A string value.