Class QueryRecords
java.lang.Object
software.amazon.awssdk.services.redshiftdata.model.QueryRecords
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<QueryRecords.Builder,QueryRecords>
@Generated("software.amazon.awssdk:codegen")
public final class QueryRecords
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<QueryRecords.Builder,QueryRecords>
The results of the SQL statement.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interfacestatic enum -
Method Summary
Modifier and TypeMethodDescriptionstatic QueryRecords.Builderbuilder()final StringThe results of the SQL statement in CSV format.final booleanfinal booleanequalsBySdkFields(Object obj) static QueryRecordsfromCsvRecords(String csvRecords) Create an instance of this class withcsvRecords()initialized to the given value.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends QueryRecords.Builder>final StringtoString()Returns a string representation of this object.type()Retrieve an enum value representing which member of this object is populated.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
csvRecords
The results of the SQL statement in CSV format.
- Returns:
- The results of the SQL statement in CSV format.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<QueryRecords.Builder,QueryRecords>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
fromCsvRecords
Create an instance of this class withcsvRecords()initialized to the given value.The results of the SQL statement in CSV format.
- Parameters:
csvRecords- The results of the SQL statement in CSV format.
-
type
Retrieve an enum value representing which member of this object is populated. When this class is returned in a service response, this will beQueryRecords.Type.UNKNOWN_TO_SDK_VERSIONif the service returned a member that is only known to a newer SDK version. When this class is created directly in your code, this will beQueryRecords.Type.UNKNOWN_TO_SDK_VERSIONif zero members are set, andnullif more than one member is set. -
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-