Class SubStatementData
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<SubStatementData.Builder,SubStatementData>
Information about an SQL statement.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic SubStatementData.Builderbuilder()final InstantThe date and time (UTC) the statement was created.final Longduration()The amount of time in nanoseconds that the statement ran.final booleanfinal booleanequalsBySdkFields(Object obj) final Stringerror()The error message from the cluster if the SQL statement encountered an error while running.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final BooleanA value that indicates whether the statement has a result set.final Stringid()The identifier of the SQL statement.final StringThe SQL statement text.final LongThe SQL statement identifier.final LongEither the number of rows returned from the SQL statement or the number of rows affected.final LongThe size in bytes of the returned results.static Class<? extends SubStatementData.Builder>final StatementStatusStringstatus()The status of the SQL statement.final StringThe status of the SQL statement.final StringtoString()Returns a string representation of this object.final InstantThe date and time (UTC) that the statement metadata was last updated.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
id
The identifier of the SQL statement. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. A suffix indicates the number of the SQL statement. For example,
d9b6c0c9-0747-4bf4-b142-e8883122f766:2has a suffix of:2that indicates the second SQL statement of a batch query.- Returns:
- The identifier of the SQL statement. This value is a universally unique identifier (UUID) generated by
Amazon Redshift Data API. A suffix indicates the number of the SQL statement. For example,
d9b6c0c9-0747-4bf4-b142-e8883122f766:2has a suffix of:2that indicates the second SQL statement of a batch query.
-
duration
The amount of time in nanoseconds that the statement ran.
- Returns:
- The amount of time in nanoseconds that the statement ran.
-
error
The error message from the cluster if the SQL statement encountered an error while running.
- Returns:
- The error message from the cluster if the SQL statement encountered an error while running.
-
status
The status of the SQL statement. An example is the that the SQL statement finished.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnStatementStatusString.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- The status of the SQL statement. An example is the that the SQL statement finished.
- See Also:
-
statusAsString
The status of the SQL statement. An example is the that the SQL statement finished.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnStatementStatusString.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- The status of the SQL statement. An example is the that the SQL statement finished.
- See Also:
-
createdAt
The date and time (UTC) the statement was created.
- Returns:
- The date and time (UTC) the statement was created.
-
updatedAt
The date and time (UTC) that the statement metadata was last updated.
- Returns:
- The date and time (UTC) that the statement metadata was last updated.
-
queryString
The SQL statement text.
- Returns:
- The SQL statement text.
-
resultRows
Either the number of rows returned from the SQL statement or the number of rows affected. If result size is greater than zero, the result rows can be the number of rows affected by SQL statements such as INSERT, UPDATE, DELETE, COPY, and others. A
-1indicates the value is null.- Returns:
- Either the number of rows returned from the SQL statement or the number of rows affected. If result size
is greater than zero, the result rows can be the number of rows affected by SQL statements such as
INSERT, UPDATE, DELETE, COPY, and others. A
-1indicates the value is null.
-
resultSize
The size in bytes of the returned results. A
-1indicates the value is null.- Returns:
- The size in bytes of the returned results. A
-1indicates the value is null.
-
redshiftQueryId
The SQL statement identifier. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API.
- Returns:
- The SQL statement identifier. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API.
-
hasResultSet
A value that indicates whether the statement has a result set. The result set can be empty. The value is true for an empty result set.
- Returns:
- A value that indicates whether the statement has a result set. The result set can be empty. The value is true for an empty result set.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<SubStatementData.Builder,SubStatementData>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-