All Classes and Interfaces
Class
Description
The Amazon Redshift Data API operation failed because the maximum number of active sessions exceeded.
The number of active statements exceeds the limit.
An AWS Arn.
An SQL statement encountered an environmental error while running.
BatchExecuteStatementRequest MarshallerCancelStatementRequest Marshaller
The properties (metadata) of a column.
Connection to a database failed.
DescribeStatementRequest Marshaller
Represents the output for the
RedshiftDataClient.describeTablePaginator(software.amazon.awssdk.services.redshiftdata.model.DescribeTableRequest)
operation which is a paginated operation.
Represents the output for the
RedshiftDataAsyncClient.describeTablePaginator(software.amazon.awssdk.services.redshiftdata.model.DescribeTableRequest)
operation which is a paginated operation.DescribeTableRequest MarshallerLink between an endpoint property and the
AwsEndpointAttribute it represents.
The SQL statement encountered an environmental error while running.
ExecuteStatementRequest Marshaller
A data value in a column.
Represents the output for the
RedshiftDataClient.getStatementResultPaginator(software.amazon.awssdk.services.redshiftdata.model.GetStatementResultRequest)
operation which is a paginated operation.
Represents the output for the
RedshiftDataAsyncClient.getStatementResultPaginator(software.amazon.awssdk.services.redshiftdata.model.GetStatementResultRequest)
operation which is a paginated operation.GetStatementResultRequest Marshaller
Represents the output for the
RedshiftDataClient.getStatementResultV2Paginator(software.amazon.awssdk.services.redshiftdata.model.GetStatementResultV2Request)
operation which is a paginated operation.
Represents the output for the
RedshiftDataAsyncClient.getStatementResultV2Paginator(software.amazon.awssdk.services.redshiftdata.model.GetStatementResultV2Request)
operation which is a paginated operation.GetStatementResultV2Request MarshallerIdentifiers for variables declared within the rule engine, e.g.
The Amazon Redshift Data API operation failed due to invalid input.
Represents the output for the
RedshiftDataClient.listDatabasesPaginator(software.amazon.awssdk.services.redshiftdata.model.ListDatabasesRequest)
operation which is a paginated operation.
Represents the output for the
RedshiftDataAsyncClient.listDatabasesPaginator(software.amazon.awssdk.services.redshiftdata.model.ListDatabasesRequest)
operation which is a paginated operation.ListDatabasesRequest Marshaller
Represents the output for the
RedshiftDataClient.listSchemasPaginator(software.amazon.awssdk.services.redshiftdata.model.ListSchemasRequest)
operation which is a paginated operation.
Represents the output for the
RedshiftDataAsyncClient.listSchemasPaginator(software.amazon.awssdk.services.redshiftdata.model.ListSchemasRequest)
operation which is a paginated operation.ListSchemasRequest Marshaller
Represents the output for the
RedshiftDataClient.listStatementsPaginator(software.amazon.awssdk.services.redshiftdata.model.ListStatementsRequest)
operation which is a paginated operation.
Represents the output for the
RedshiftDataAsyncClient.listStatementsPaginator(software.amazon.awssdk.services.redshiftdata.model.ListStatementsRequest)
operation which is a paginated operation.ListStatementsRequest Marshaller
Represents the output for the
RedshiftDataClient.listTablesPaginator(software.amazon.awssdk.services.redshiftdata.model.ListTablesRequest)
operation which is a paginated operation.
Represents the output for the
RedshiftDataAsyncClient.listTablesPaginator(software.amazon.awssdk.services.redshiftdata.model.ListTablesRequest)
operation which is a paginated operation.ListTablesRequest Marshaller
The results of the SQL statement.
The Amazon Redshift Data API operation failed due to timeout.
Service client for accessing Redshift Data API Service asynchronously.
A builder for creating an instance of
RedshiftDataAsyncClient.The parameters object used to resolve the auth schemes for the RedshiftData service.
A builder for a
RedshiftDataAuthSchemeParams.An auth scheme provider for RedshiftData service.
This includes configuration specific to Redshift Data API Service that is supported by both
RedshiftDataClientBuilder and RedshiftDataAsyncClientBuilder.Service client for accessing Redshift Data API Service.
A builder for creating an instance of
RedshiftDataClient.The parameters object used to resolve an endpoint for the RedshiftData service.
An endpoint provider for RedshiftData.
Class to expose the service client settings to the user.
A builder for creating a
RedshiftDataServiceClientConfiguration
The Amazon Redshift Data API operation failed due to a missing resource.
Represents a URL to be used internally for endpoint resolution.
A parameter used in a SQL statement.
The SQL statement to run.
Information about an SQL statement.
The properties of a table.
The Amazon Redshift Data API operation failed due to invalid input.
Base class for the types of values computable by the
RuleEngine.An array value.
A boolean value.
An integer value.
A record (map) value.
A string value.